#delimit;
clear all;
set more off;

global  do "C:\Users\User\Documents\Vogl\Nepal";

* Younger Cohort empirics;
use "$do\dataset96.dta", clear;

append using "$do\dataset01.dta";
append using "$do\dataset06.dta";
append using "$do\dataset11.dta";

rename order birthorder;
rename v008 date;
rename v012 agewoman;
rename v013 agegroup;
rename v016 day;
rename v017 calendar;
rename v025 rural;
replace rural=rural-1;
rename v106 educwoman;
rename v107 gradewoman;
rename v130 religion;
rename v131 ethnic;
rename v133 educyears;
rename v139 state;
rename age agechild;
rename v701 educhusband;
rename v702 educyearshusband;

gen year=1900+int((date-1)/12);

gen singleton=(twin==0);
gen coresid=(liveswith==0);
replace gender=gender-1;

gen edprimwoman=(educwoman==1 & educyears>0 & educyears<99);
gen edsecwoman=(educwoman==2 & educyears>0 & educyears<99);
gen edhighwoman=(educwoman==3 & educyears>0 & educyears<99);
gen noedwoman=(educwoman==0);

gen edprimhus=(educhusband==1 & educyearshus>0 & educyearshus<99);
gen edsechus=(educhusband==2 & educyearshus>0 & educyearshus<99);
gen edhighhus=(educhusband==3 & educyearshus>0 & educyearshus<99);
gen noedhus=(educhus==0);

keep if agechild<.;

label define gender 0 "male" 1 "female";
label val gender gender;

sort iid birthorder;

by iid: gen order=_n;

by iid: gen orderreverse=_N-_n+1;

tsset iid order;

gen ysgender=L.gender;
label var ysgender "younger sibling gender";
label val ysgender gender;

gen ysagegap=agechild-L.agechild;
label var ysagegap "younger sibling age gap";

tsset iid orderreverse;

gen osgender=L.gender;
label var osgender "older sibling gender";
label val osgender gender;

gen osagegap=agechild-L.agechild;
label var osagegap "older sibling age gap";

sort iid order;

save "$do\empirics_pooled.dta", replace;

reg coresid ysgender rural agewoman ysagegap edprim* edsec* edhigh* if agechild>=15 & agechild<=24 & gender==1;
* reg coresid ysgender rural noed* if agechild>=15 & agechild<=24 & gender==1;
outreg2 using "$do\youngersiblingeffect.doc", replace ctitle (Younger Sibling Effect);

reg coresid osgender rural agewoman osagegap edprim* edsec* edhigh* if agechild>=15 & agechild<=24 & gender==1;
* reg coresid osgender rural noed* if agechild>=15 & agechild<=24 & gender==1;
outreg2 using "$do\oldersiblingeffect.doc", replace ctitle (Older Sibling Effect);

* mean of coresidence among women with younger brother;
sum coresid if agechild>=15 & agechild<=24 & gender==1 & ysgender==0;

*reg coresid ysgender rural agewoman ysagegap edprim* edsec* edhigh* if wave==3 & agechild>=15 & agechild<=24 & gender==1;
*reg coresid osgender rural agewoman osagegap edprim* edsec* edhigh* if wave==3 & agechild>=15 & agechild<=24 & gender==1;

* Older Cohort empirics;
use "$do\siblings.dta", clear;

rename v008 date;
rename v011 mob;
rename v012 agewoman;
rename v013 agegroup;
rename v016 day;
rename v017 calendar;
rename v025 rural;
replace rural=rural-1;
rename v106 educwoman;
rename v107 highestgradewoman;
rename v130 religion;
rename v131 ethnic;
rename v133 educyears;
rename v139 state;
rename v511 age1stmarr;
rename v701 educhusband;
rename v702 highestgradehusband;
rename v705 occuphusband;

gen ysgender=.;
gen agegap=.;

forvalues i=10(1)20 {;
	local j=30-`i';
    replace ysgender=(mm1_`j'==2) if (mm1_`j'<3) & (mm4_`j'>mob) & mm2_`j'==1;
	replace agegap=agewoman-mm3_`j' if (mm1_`j'<3) & (mm4_`j'>mob) & mm2_`j'==1;
};

forvalues i=1(1)9 {;
	local j=10-`i';
    replace ysgender=(mm1_0`j'==2) if (mm1_0`j'<3) & (mm4_0`j'>mob) & mm2_0`j'==1;
	replace agegap=agewoman-mm3_0`j' if (mm1_0`j'<3) & (mm4_0`j'>mob) & mm2_0`j'==1;
};


gen agegap2=agegap^2;

gen age1stbirth=.;

forvalues i=1(1)9 {;
    replace age1stbirth=int((b3_x_0`i'-mob)/12) if b3_x_0`i'<.;
};

forvalues i=10(1)17 {;
    replace age1stbirth=int((b3_x_`i'-mob)/12) if b3_x_`i'<.;
};

local la=25;
local ua=49;

* age at first marriage;
reg age1stmarr ysgender agegap agegap2 rural if agewoman>=`la' & agewoman<=`ua';
outreg2 using "$do\age1stmarr.doc", replace ctitle (Age at First Marriage);

* age at first childbearing;
reg age1stbirth ysgender agegap agegap2 rural if agewoman>=`la' & agewoman<=`ua';
outreg2 using "$do\age1stbirth.doc", replace ctitle (Age at First Birth);

* woman's education;
reg highestgradewoman ysgender agegap agegap2 rural if agewoman>=`la' & agewoman<=`ua';
outreg2 using "$do\womaneduc.doc", replace ctitle (Woman's Education);

* husband's skilled occupation;
gen skilledhusband=(occuphusband>=1 & occuphusband<=3) | (occuphusband>=7 & occuphusband<=8);
replace skilledhusband=. if occuphusband<1 | occuphusband>9;

reg skilledhusband ysgender agegap agegap2 rural if agewoman>=`la' & agewoman<=`ua';
outreg2 using "$do\husbandskills.doc", replace ctitle (Husband's Skills);

* husband's education;
reg highestgradehusband ysgender agegap agegap2 rural if agewoman>=`la' & agewoman<=`ua';
outreg2 using "$do\husbandeduc.doc", replace ctitle (Husband's Education);

